blosc2.Filter
=============

.. currentmodule:: blosc2

.. autoclass:: Filter
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Filter.NOFILTER
      ~Filter.SHUFFLE
      ~Filter.BITSHUFFLE
      ~Filter.DELTA
      ~Filter.TRUNC_PREC
      ~Filter.NDCELL
      ~Filter.NDMEAN
   